# Generated by roxygen2: do not edit by hand

S3method(cbind,paar)
S3method(print,paar)
S3method(print,summary.paar)
S3method(summary,paar)
export(compare_zone)
export(depurate)
export(fuzzy_k_means)
export(kmspc)
export(spatial_t_test)
